@@ -17,7 +17,6 @@ from .utils import (
 )
 from ..interfaces import (
     Project,
-    ProjectVisibility,
     QuotaGroup,
     TrainTask,
 )
@@ -194,8 +193,7 @@ def _get_or_create_project(project_id: Optional[str]=None,
     except:
         name = project_name or f"PROJ_{generate_random_name()}"
         description = project_name or "SDK_QUICKSTART"
-        project = Project(name=name, description=description,
-                          visibility=ProjectVisibility.PRIVATE)
+        project = Project(name=name, description=description)
         project.save()
         return project
 
@@ -225,7 +223,9 @@ def _create_train_task(name: str,
                        mounts: Optional[Union[Dict[str, List[Resource]], Dict[str, Resource]]]=None,
                        algorithm_git_ref: Optional[str]=None,
                        resource_request: Optional[List[Dict[str, Dict[str, int]]]]=None,
-                       description: Optional[str]=None):
+                       description: Optional[str]=None,
+                       num_nodes: Optional[int]=1,
+                       nproc_per_node: Optional[int]=1):
     resource_ids = []
     train_params = hyperparams
     for k, v in mounts.items():
@@ -244,6 +244,8 @@ def _create_train_task(name: str,
         train_params=json.dumps(train_params),
         resource_request=resource_request,
         description=description,
+        num_nodes=num_nodes,
+        nproc_per_node=nproc_per_node,
     )
     train_task.save()
     train_task.get_detail()
@@ -274,7 +276,9 @@ def quick_train(algorithm_id: Optional[str]=None,
                 resource_request: Optional[List[Dict[str, Dict[str, int]]]]=None,
                 quota_group_name: Optional[str]=None,
                 quota_group_request: Optional[Dict[str, int]]=None,
-                task_description: Optional[str]=None):
+                task_description: Optional[str]=None,
+                num_nodes: Optional[int]=1,
+                nproc_per_node: Optional[int]=1):
     """
     本地算法快速训练接口。
 
@@ -386,6 +390,10 @@ def quick_train(algorithm_id: Optional[str]=None,
         且参数 :obj:`algorithm_force_update` 为 :obj:`True` 时，
         则Anylearn在自动提交本地算法变更时，
         会将此值作为commit message同步至远端
+    num_nodes : :obj:`int`, optional
+        分布式训练需要的节点数。
+    nproc_per_node : :obj:`int`, optional
+        分布式训练每个节点运行的进程数。
 
     Returns
     -------
@@ -483,6 +491,8 @@ def quick_train(algorithm_id: Optional[str]=None,
         mounts=mounts,
         resource_request=resource_request,
         description=task_description,
+        num_nodes=num_nodes,
+        nproc_per_node=nproc_per_node,
     )
 
     DB().create_or_update_train_task(train_task=train_task)
