@@ -77,7 +77,7 @@ class TestQuickTrain(BaseTestCase):
         responses.add(responses.GET, url=self._url("algorithm/query?id=ALGO001"),
                       match_querystring=True, json=[{
                           'id': "ALGO001",
-                          'name': "TestAlgo1",
+                          'name': "Test-Algo_1.1",
                           'description': "test",
                           'state': ResourceState.READY,
                           'visibility': ResourceVisibility.PUBLIC,
@@ -95,7 +95,7 @@ class TestQuickTrain(BaseTestCase):
                           'follows_anylearn_norm': False,
                           'entrypoint_training': "python train.py",
                           'output_training': "output",
-                          'git_address': "http://anylearn.testing/anylearn/TestAlgo1.git",
+                          'git_address': "http://anylearn.testing/anylearn/Test-Algo_1.1.git",
                           'git_migrated': True,
                       }],
                       status=200)
@@ -147,6 +147,7 @@ class TestQuickTrain(BaseTestCase):
 
         train_task, algo, dset, project = quick_train(
             algorithm_dir=FAKE_ALGO_OK,
+            algorithm_name="Test-Algo_1.1",
             dataset_dir=FAKE_DSET,
             entrypoint="python main.py",
             output="output",
@@ -158,9 +159,9 @@ class TestQuickTrain(BaseTestCase):
         
         self.assertIsInstance(train_task, TrainTask)
         self.assertEqual(train_task.id, "TRAI001")
-        self.assertTrue((FAKE_ALGO_OK / "anylearn_tools.py").exists())
         self.assertIsInstance(algo, Algorithm)
         self.assertEqual(algo.id, "ALGO001")
+        self.assertEqual(algo.name, "Test-Algo_1.1")
         self.assertIsInstance(dset, Dataset)
         self.assertEqual(dset.id, "DSET001")
         self.assertIsInstance(project, Project)
@@ -176,6 +177,36 @@ class TestQuickTrain(BaseTestCase):
         self.assertIsInstance(e, AnyLearnException)
         self.assertEqual(e.msg, "Missing 'requirements.txt' in algorithm directory")
 
+    @responses.activate
+    def test_quick_train_ko_algo_name_not_standard(self):
+        # Stub mirror list
+        responses.add(responses.GET, url=self._url("mirror/list"),
+                      json=[
+                          {
+                              'id': "MIRR001",
+                              'name': "Test001",
+                              'requirements': "test==0.0.1",
+                          },
+                          {
+                              'id': "MIRR002",
+                              'name': "QUICKSTART",
+                              'requirements': "test==0.0.2",
+                          },
+                      ],
+                      status=200)
+        with self.assertRaises(AnyLearnException) as ctx:
+            train_task = quick_train(algorithm_dir=FAKE_ALGO_OK,
+                                     algorithm_name="abc@123",
+                                     dataset_dir=FAKE_DSET,
+                                     entrypoint="python main.py",
+                                     output="output")
+        e = ctx.exception
+        self.assertIsInstance(e, AnyLearnException)
+        self.assertEqual(
+            e.msg,
+            "Algorithm name should contain only alphanumeric, dash ('-'), underscore ('_') and dot ('.') characters"
+        )
+
     @responses.activate
     def test_quick_train_ko_mirror_not_found(self):
         responses.add(responses.GET, url=self._url("mirror/list"),
@@ -434,7 +465,6 @@ class TestQuickTrain(BaseTestCase):
                     'create_time': "2021-03-01 23:59:59",
                     'finish_time': "",
                     'envs': "",
-                    'gpu_num': 1,
                 }],
                 status=200)
 
@@ -456,7 +486,6 @@ class TestQuickTrain(BaseTestCase):
                     'create_time': "2021-03-01 23:59:59",
                     'finish_time': "",
                     'envs': "",
-                    'gpu_num': 1,
                 }],
                 status=200)
 
@@ -478,7 +507,6 @@ class TestQuickTrain(BaseTestCase):
                     'create_time': "2021-03-01 23:59:59",
                     'finish_time': "",
                     'envs': "",
-                    'gpu_num': 1,
                 }],
                 status=200)
  
