@@ -23,9 +23,7 @@ class TestTrainTask(BaseTestCase):
                           'name': "TestTrainTask1",
                           'description': "test",
                           'state': TrainTaskState.RUNNING,
-                          'visibility': 2,
                           'creator_id': "USER001",
-                          'owner': ["USER001"],
                           'project_id': "PROJ001",
                           'algorithm_id': "ALGO001",
                           'algorithm_git_ref': None,
@@ -44,9 +42,7 @@ class TestTrainTask(BaseTestCase):
         self.assertEqual(train_task.name, "TestTrainTask1")
         self.assertEqual(train_task.description, "test")
         self.assertEqual(train_task.state, TrainTaskState.RUNNING)
-        self.assertEqual(train_task.visibility, 2)
         self.assertEqual(train_task.creator_id, "USER001")
-        self.assertIsInstance(train_task.owner, list)
         self.assertEqual(train_task.project_id, "PROJ001")
         self.assertEqual(train_task.algorithm_id, "ALGO001")
         if train_task.train_params:
@@ -64,9 +60,7 @@ class TestTrainTask(BaseTestCase):
                           'name': "TestTrainTask2",
                           'description': "test",
                           'state': TrainTaskState.RUNNING,
-                          'visibility': 2,
                           'creator_id': "USER002",
-                          'owner': ["USER002"],
                           'project_id': "PROJ002",
                           'algorithm_id': "ALGO002",
                           'algorithm_git_ref': None,
@@ -84,9 +78,7 @@ class TestTrainTask(BaseTestCase):
         self.assertEqual(train_task.name, "TestTrainTask2")
         self.assertEqual(train_task.description, "test")
         self.assertEqual(train_task.state, TrainTaskState.RUNNING)
-        self.assertEqual(train_task.visibility, 2)
         self.assertEqual(train_task.creator_id, "USER002")
-        self.assertIsInstance(train_task.owner, list)
         self.assertEqual(train_task.project_id, "PROJ002")
         self.assertEqual(train_task.algorithm_id, "ALGO002")
         if train_task.train_params:
